@@ -187,7 +187,7 @@ class ModelInstance:
     def __init__(self, model_id: str = None, supp_id: str = None, description: str = None, instance_id = None):
         self.supp_id = supp_id
         self.description = description
-        instance_id = instance_id
+        self.instance_id = instance_id
         self.model_id = model_id
         self.chat_history = self.get_chat_history()
         self.is_deployed = self.instance_id not in models['model_id'].model_instances
